@@ -5,10 +5,6 @@
 /* -----------------------------------------------------------------------------
  * CHOLMOD/Core Module.  Copyright (C) 2005-2006,
  * Univ. of Florida.  Author: Timothy A. Davis
- * The CHOLMOD/Core Module is licensed under Version 2.1 of the GNU
- * Lesser General Public License.  See lesser.txt for a text of the license.
- * CHOLMOD is also available under other licenses; contact authors for details.
- * http://www.cise.ufl.edu/research/sparse
  * -------------------------------------------------------------------------- */
 
 /* Core utility routines for the cholmod_common object:
@@ -57,6 +53,8 @@ int CHOLMOD(start)
     cholmod_common *Common
 )
 {
+    int k ;
+
     if (Common == NULL)
     {
 	return (FALSE) ;
@@ -86,41 +84,19 @@ int CHOLMOD(start)
     /* memory management routines */
     /* ---------------------------------------------------------------------- */
 
-    /* The user can replace cholmod's memory management routines by redefining
-     * these function pointers. */
-
-#ifndef NMALLOC
-    /* stand-alone ANSI C program */
-    Common->malloc_memory  = malloc ;
-    Common->free_memory    = free ;
-    Common->realloc_memory = realloc ;
-    Common->calloc_memory  = calloc ;
-#else
-    /* no memory manager defined at compile-time; MUST define one at run-time */
-    Common->malloc_memory  = NULL ;
-    Common->free_memory    = NULL ;
-    Common->realloc_memory = NULL ;
-    Common->calloc_memory  = NULL ;
-#endif
+        /* moved to SuiteSparse_config */
 
     /* ---------------------------------------------------------------------- */
     /* complex arithmetic routines */
     /* ---------------------------------------------------------------------- */
 
-    Common->complex_divide = CHOLMOD(divcomplex) ;
-    Common->hypotenuse = CHOLMOD(hypot) ;
+        /* moved to SuiteSparse_config */
 
     /* ---------------------------------------------------------------------- */
     /* print routine */
     /* ---------------------------------------------------------------------- */
 
-#ifndef NPRINT
-    /* stand-alone ANSI C program */
-    Common->print_function = printf ;
-#else
-    /* printing disabled */
-    Common->print_function = NULL ;
-#endif
+        /* moved to SuiteSparse_config */
 
     /* ---------------------------------------------------------------------- */
     /* workspace */
@@ -167,7 +143,84 @@ int CHOLMOD(start)
     /* Common->called_nd is TRUE if cholmod_analyze called or NESDIS */
     Common->called_nd = FALSE ;
 
+    Common->blas_ok = TRUE ;    /* false if BLAS int overflow occurs */
+
+    /* ---------------------------------------------------------------------- */
+    /* default SuiteSparseQR knobs and statististics */
+    /* ---------------------------------------------------------------------- */
+
+    for (k = 0 ; k < 10 ; k++) Common->SPQR_istat [k] = 0 ;
+
+    Common->SPQR_flopcount_bound = 0 ;   /* upper bound on flop count */
+    Common->SPQR_tol_used = 0 ;          /* tolerance used */
+    Common->SPQR_norm_E_fro = 0 ;        /* Frobenius norm of dropped entries */
+
+    Common->SPQR_grain = 1 ;    /* no Intel TBB multitasking, by default */
+    Common->SPQR_small = 1e6 ;  /* target min task size for TBB */
+    Common->SPQR_shrink = 1 ;   /* controls SPQR shrink realloc */
+    Common->SPQR_nthreads = 0 ; /* 0: let TBB decide how many threads to use */
+
+    Common->SPQR_flopcount = 0 ;         /* flop count for SPQR */
+    Common->SPQR_analyze_time = 0 ;      /* analysis time for SPQR */
+    Common->SPQR_factorize_time = 0 ;    /* factorize time for SPQR */
+    Common->SPQR_solve_time = 0 ;        /* backsolve time for SPQR */
+
+    /* ---------------------------------------------------------------------- */
+    /* GPU initializations */
+    /* ---------------------------------------------------------------------- */
+
+    /* these are destroyed by cholmod_gpu_deallocate and cholmod_gpu_end */
+    Common->cublasHandle = NULL ;
+    Common->cublasEventPotrf [0] = NULL ;
+    Common->cublasEventPotrf [1] = NULL ;
+    Common->cublasEventPotrf [2] = NULL ;
+    for (k = 0 ; k < CHOLMOD_HOST_SUPERNODE_BUFFERS ; k++)
+    {
+        Common->gpuStream [k] = NULL ;
+        Common->updateCBuffersFree [k] = NULL ;
+    }
+    Common->updateCKernelsComplete = NULL;
+
+    /* these are destroyed by cholmod_gpu_deallocate */
+    Common->dev_mempool = NULL;
+    Common->dev_mempool_size = 0;
+    Common->host_pinned_mempool = NULL;
+    Common->host_pinned_mempool_size = 0;
+
+    Common->syrkStart = 0 ;
+
+    Common->cholmod_cpu_gemm_time = 0 ;
+    Common->cholmod_cpu_syrk_time = 0 ;
+    Common->cholmod_cpu_trsm_time = 0 ;
+    Common->cholmod_cpu_potrf_time = 0 ;
+    Common->cholmod_gpu_gemm_time = 0 ;
+    Common->cholmod_gpu_syrk_time = 0 ;
+    Common->cholmod_gpu_trsm_time = 0 ;
+    Common->cholmod_gpu_potrf_time = 0 ;
+    Common->cholmod_assemble_time = 0 ;
+    Common->cholmod_assemble_time2 = 0 ;
+
+    Common->cholmod_cpu_gemm_calls = 0 ;
+    Common->cholmod_cpu_syrk_calls = 0 ;
+    Common->cholmod_cpu_trsm_calls = 0 ;
+    Common->cholmod_cpu_potrf_calls = 0 ;
+
+    Common->cholmod_gpu_gemm_calls = 0 ;
+    Common->cholmod_gpu_syrk_calls = 0 ;
+    Common->cholmod_gpu_trsm_calls = 0 ;
+    Common->cholmod_gpu_potrf_calls = 0 ;
+
+    Common->maxGpuMemBytes = 0;
+    Common->maxGpuMemFraction = 0.0;
+
+    /* SPQR statistics and settings */
+    Common->gpuMemorySize = 1 ;         /* default: no GPU memory available */
+    Common->gpuKernelTime = 0.0 ;
+    Common->gpuFlops = 0 ;
+    Common->gpuNumKernelLaunches = 0 ;
+
     DEBUG_INIT ("cholmod start", Common) ;
+
     return (TRUE) ;
 }
 
@@ -304,6 +357,17 @@ int CHOLMOD(defaults)
     /* COLAMD for A*A', AMD for A */
     Common->method [8].ordering = CHOLMOD_COLAMD ;
 
+    /* ---------------------------------------------------------------------- */
+    /* GPU configuration and statistics */
+    /* ---------------------------------------------------------------------- */
+
+#ifdef DLONG
+    Common->useGPU = EMPTY ;
+#else
+    /* GPU acceleration is not supported for int version of CHOLMOD */
+    Common->useGPU = 0 ;
+#endif
+
     return (TRUE) ;
 }
 
@@ -517,6 +581,10 @@ int CHOLMOD(free_work)
     Common->nrow = 0 ;
     Common->iworksize = 0 ;
     Common->xworksize = 0 ;
+
+#ifdef GPU_BLAS
+    CHOLMOD(gpu_deallocate) (Common) ;
+#endif
     return (TRUE) ;
 }
 
@@ -532,7 +600,7 @@ int CHOLMOD(free_work)
  * workspace: Flag (nrow).  Does not modify Flag if nrow is zero.
  */
 
-UF_long CHOLMOD(clear_flag)
+SuiteSparse_long CHOLMOD(clear_flag)
 (
     cholmod_common *Common
 )
@@ -655,3 +723,22 @@ double CHOLMOD(dbound)	/* returns modified diagonal entry of D */
     }
     return (dj) ;
 }
+
+
+/* ========================================================================== */
+/* === scorecomp ============================================================ */
+/* ========================================================================== */
+
+/* For sorting descendant supernodes with qsort */
+int CHOLMOD(score_comp) (struct cholmod_descendant_score_t *i, 
+			       struct cholmod_descendant_score_t *j)
+{
+  if ((*i).score < (*j).score)
+    {
+	return (1) ;
+    }
+    else
+    {
+	return (-1) ;
+    }
+}
