@@ -23,6 +23,8 @@
 #include <cuda_runtime.h>
 #endif
 
+// #define HACK
+
 #define MINSIZE (64 * 1024 * 1024)
 
 /* ========================================================================== */
@@ -108,6 +110,10 @@ int CHOLMOD(gpu_memorysize)      /* returns 1 on error, 0 otherwise */
     {
         /* printf ("quick %lu\n", s) ; */
         *available_mem = s;
+#ifdef HACK
+        *total_mem     /= 2;
+        *available_mem /= 2;
+#endif
         return (0) ;  /* no error */
     }
 
@@ -138,6 +144,10 @@ int CHOLMOD(gpu_memorysize)      /* returns 1 on error, 0 otherwise */
 
 #endif
 
+#ifdef HACK
+        *total_mem     /= 2;
+        *available_mem /= 2;
+#endif
     return (0) ; /* no error */
 }
 
